package com.ericsson.ims.mtas.xdms.cai3g.factory;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.ericsson.ims.mtas.xdms.schema.cai3g.ObjectFactory;

public class Cai3gObjectFactory extends ObjectFactory implements ICai3gObjectFactory
{
	public static Logger logger = LoggerFactory.getLogger(Cai3gObjectFactory.class);

	public Cai3gObjectFactory()
	{

	}
}
