package com.ericsson.ims.mtas.xdms.communication.diversion.binder;

import com.ericsson.ims.mtas.xdms.common.binder.IGenericBinder;

public interface ICommunicationDiversionBinder extends IGenericBinder
{
	public abstract void marshall(Object o);
}
