package com.ericsson.ims.mtas.xdms.communication.diversion.factory;

import com.ericsson.ims.mtas.xdms.schema.communication.diversion.ObjectFactory;

public class CommunicationDiversionObjectFactory extends ObjectFactory implements ICommunicationDiversionObjectFactory
{
	public CommunicationDiversionObjectFactory()
	{

	}
}
