package com.ericsson.ims.mtas.xdms.aggregated.service.binder;

import javax.xml.bind.JAXBException;
import javax.xml.transform.Source;

import com.ericsson.ims.mtas.xdms.common.binder.IGenericBinder;

public interface IAggregatedServiceBinder extends IGenericBinder
{
	public abstract void marshall(Object o) throws JAXBException;

	public abstract Object unmarshall(Source source);
}
