package com.ericsson.ims.mtas.xdms.cai3g.document;

import static org.junit.Assert.assertNotNull;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

public class Cai3gDocumentTest
{
	String user = "admin";

	String pwd = "adminadmin";

	String sessionId = "2728391237801273";

	String moType = "MMTel@http://schemas.ericsson.com/mtas/mmtel/cai3g";

	String id = "sip:lulseged.zerfu@ericsson.com";

	ICai3gDocument document;

	@BeforeClass
	public static void setUpBeforeClass() throws Exception
	{
	}

	@AfterClass
	public static void tearDownAfterClass() throws Exception
	{
	}

	@Before
	public void setUp() throws Exception
	{
		document = new Cai3gDocument();
	}

	@After
	public void tearDown() throws Exception
	{
	}

	@Test
	public void testGetFactory()
	{
		assertNotNull(document.getClass());
	}

	@Test
	public void testCreateCreate()
	{
		document.createCreate(moType);
	}

	@Test
	public void testCreateGet()
	{
		document.createGet(moType);
	}

	@Test
	public void testCreateLogin()
	{
		document.createLogin(user, pwd);
	}

	@Test
	public void testCreateLoginOut()
	{
		document.createLoginOut(sessionId);
	}

	@Test
	public void testCreateSet()
	{
		document.createSet(moType);
	}

	@Test
	public void testCreateDelete()
	{
		document.createDelete(moType);
	}

	@Test
	public void testCreateSubscribe()
	{
		document.createSubscribe();
	}

	@Test
	public void testCreateNotify()
	{
		document.createNotify();
	}

	@Test
	public void testCreateSearch()
	{
		document.createSearch();
	}
}
