package com.ericsson.ims.mtas.xdms.common.types.document;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.ericsson.ims.mtas.xdms.common.types.factory.CommonTypesObjectFactory;
import com.ericsson.ims.mtas.xdms.schema.mtas.common.types.ObjectFactory;

public class CommonTypesDocument implements ICommonTypesDocument
{
	public static Logger logger = LoggerFactory.getLogger(CommonTypesDocument.class);

	private CommonTypesObjectFactory factory;

	public CommonTypesDocument()
	{
		factory = new CommonTypesObjectFactory();
	}

	public ObjectFactory getFactory()
	{
		return factory;
	}

	public void createPublicIdentity()
	{

	}
}
