package com.ericsson.ims.mtas.xdms.communication.diversion.binder;

import javax.xml.bind.JAXBException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.ericsson.ims.mtas.xdms.common.binder.GenericBinder;

public class CommunicationDiversionBinder extends GenericBinder implements ICommunicationDiversionBinder
{
	public static Logger logger = LoggerFactory.getLogger(CommunicationDiversionBinder.class);

	// protected static String instance = "com.ericsson.ims.mtas.xdms.schema.cai3g:"
	// + "com.ericsson.ims.mtas.xdms.schema.communication.diversion:"
	// + "com.ericsson.ims.mtas.xdms.schema.mtas.common.types";

	protected static String[] preDefinedNameSpace = {};

	public CommunicationDiversionBinder()
	{
		super(preDefinedNameSpace);
	}

	@Override
	public void marshall(Object o)
	{
		try
		{
			marshaller.marshal(o, System.out);
		}
		catch (JAXBException e)
		{
			checkValidation();
			e.printStackTrace();
		}
	}
}
