package com.ericsson.ims.mtas.xdms.common.types.factory;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.ericsson.ims.mtas.xdms.schema.mtas.common.types.ObjectFactory;

public class CommonTypesObjectFactory extends ObjectFactory implements ICommonTypesObjectFactory
{
	public static Logger logger = LoggerFactory.getLogger(CommonTypesObjectFactory.class);

	public CommonTypesObjectFactory()
	{

	}
}
