package com.ericsson.ims.mtas.xdms.aggregated.service.document;

import com.ericsson.ims.mtas.xdms.schema.cai3g.Create;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Delete;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Get;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Set;
import com.ericsson.ims.mtas.xdms.schema.communication.diversion.CreateMMTel;

public interface IAggregatedServiceDocument
{
	public abstract CreateMMTel createDefault();

	public abstract Create createCreate(String moType, String id);

	public abstract Set createSet(String moType, String id);

	public abstract Get createGet(String moType, String id);

	public abstract Delete createDelete(String moType, String id);
}
