package com.ericsson.ims.mtas.xdms.cai3g.document;

import com.ericsson.ims.mtas.xdms.schema.cai3g.Create;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Delete;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Get;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Login;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Logout;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Notify;
import com.ericsson.ims.mtas.xdms.schema.cai3g.ObjectFactory;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Search;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Set;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Subscribe;

public interface ICai3gDocument
{
	public abstract ObjectFactory getFactory();

	public abstract Login createLogin(String user, String pwd);

	public abstract Create createCreate(String moType);

	public abstract Get createGet(String moType);

	public abstract Set createSet(String moType);

	public abstract Delete createDelete(String moType);

	public abstract Search createSearch();

	public abstract Notify createNotify();

	public abstract Subscribe createSubscribe();

	public abstract Logout createLoginOut(String id);
}
