package com.ericsson.ims.mtas.xdms.cai3g.binder;

import com.ericsson.ims.mtas.xdms.common.binder.IGenericBinder;

public interface ICai3gBinder extends IGenericBinder
{

	public abstract void marshall(Object o);

}
