package com.ericsson.ims.mtas.xdms.communication.diversion.document;

import javax.xml.bind.JAXBElement;

import com.ericsson.ims.mtas.xdms.schema.cai3g.Create;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Delete;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Get;
import com.ericsson.ims.mtas.xdms.schema.cai3g.Set;
import com.ericsson.ims.mtas.xdms.schema.communication.diversion.CdivOperatorConfigurationType;
import com.ericsson.ims.mtas.xdms.schema.communication.diversion.CdivUserConfigurationType;
import com.ericsson.ims.mtas.xdms.schema.communication.diversion.CommunicationDiversionType;
import com.ericsson.ims.mtas.xdms.schema.communication.diversion.ObjectFactory;

public interface ICommunicationDiversionDocument
{
	public abstract ObjectFactory getFactory();

	public abstract JAXBElement<CommunicationDiversionType> createDefault();

	public abstract JAXBElement<CdivUserConfigurationType> userConfiguration();

	public abstract JAXBElement<CdivOperatorConfigurationType> operatorConfiguration();

	public abstract JAXBElement<String> createPublicIdentity(String id);

	public abstract Create createCreate(String moType, String id);

	public abstract Get createGet(String moType, String id);

	public abstract Set createSet(String moType, String id);

	public abstract Delete createDelete(String moType, String id);
}
